# pyaoa - Automatic Angle-of-Attack Analysis

Automatic pre- and postprocessing of external aerodynamic simulations of arbitrary numbers of objects to analyze at different angles-of-attack $\alpha$.

## Installation

## Examples

## User Guide